@@ -28,6 +28,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Alert
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class AlertPolicy
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -58,12 +64,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class BasicService
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class BasicSli
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class BooleanTest
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class BucketOptions
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -76,6 +94,18 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class CloudFunctionV2Target
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class CloudRun
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ClusterIstio
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -142,12 +172,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Criteria
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Custom
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Daily
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Distribution
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -208,6 +250,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ForecastOptions
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class GetNotificationChannelVerificationCodeRequest
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -220,6 +268,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class GkeNamespace
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GkeService
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class GkeWorkload
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class GoogleMonitoringV3Range
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -232,6 +298,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Hourly
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class HttpCheck
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -250,6 +322,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class JsonPathMatcher
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class LabelDescriptor
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -274,12 +352,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Link
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ListAlertPoliciesResponse
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ListAlertsResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ListGroupMembersResponse
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -328,6 +418,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ListSnoozesResponse
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ListTimeSeriesResponse
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -352,6 +448,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class LogMetadata
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class MeshIstio
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -394,6 +496,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Minutes
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class MonitoredResource
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -436,6 +544,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class NotificationChannelStrategy
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class NotificationRateLimit
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -460,6 +574,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class PingConfig
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Point
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -472,6 +592,18 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class PolicySnapshot
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class PrometheusQueryLanguageCondition
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class QueryTimeSeriesRequest
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -502,6 +634,18 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ResponseStatusCode
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class RowCountTest
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class SendNotificationChannelVerificationCodeRequest
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -514,6 +658,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ServiceAgentAuthentication
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class ServiceLevelIndicator
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -526,6 +676,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Snooze
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class SourceContext
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -538,12 +694,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class SqlCondition
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Status
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class SyntheticMonitorTarget
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class TcpCheck
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -562,6 +730,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class TimeOfDay
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class TimeSeries
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -644,6 +818,26 @@ module Google
         end
       end
       
+      class Alert
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :close_time, as: 'closeTime'
+          property :log, as: 'log', class: Google::Apis::MonitoringV3::LogMetadata, decorator: Google::Apis::MonitoringV3::LogMetadata::Representation
+      
+          property :metadata, as: 'metadata', class: Google::Apis::MonitoringV3::MonitoredResourceMetadata, decorator: Google::Apis::MonitoringV3::MonitoredResourceMetadata::Representation
+      
+          property :metric, as: 'metric', class: Google::Apis::MonitoringV3::Metric, decorator: Google::Apis::MonitoringV3::Metric::Representation
+      
+          property :name, as: 'name'
+          property :open_time, as: 'openTime'
+          property :policy, as: 'policy', class: Google::Apis::MonitoringV3::PolicySnapshot, decorator: Google::Apis::MonitoringV3::PolicySnapshot::Representation
+      
+          property :resource, as: 'resource', class: Google::Apis::MonitoringV3::MonitoredResource, decorator: Google::Apis::MonitoringV3::MonitoredResource::Representation
+      
+          property :state, as: 'state'
+        end
+      end
+      
       class AlertPolicy
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -662,6 +856,7 @@ module Google
       
           property :name, as: 'name'
           collection :notification_channels, as: 'notificationChannels'
+          property :severity, as: 'severity'
           hash :user_labels, as: 'userLabels'
           property :validity, as: 'validity', class: Google::Apis::MonitoringV3::Status, decorator: Google::Apis::MonitoringV3::Status::Representation
       
@@ -671,6 +866,10 @@ module Google
       class AlertStrategy
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :auto_close, as: 'autoClose'
+          collection :notification_channel_strategy, as: 'notificationChannelStrategy', class: Google::Apis::MonitoringV3::NotificationChannelStrategy, decorator: Google::Apis::MonitoringV3::NotificationChannelStrategy::Representation
+      
+          collection :notification_prompts, as: 'notificationPrompts'
           property :notification_rate_limit, as: 'notificationRateLimit', class: Google::Apis::MonitoringV3::NotificationRateLimit, decorator: Google::Apis::MonitoringV3::NotificationRateLimit::Representation
       
         end
@@ -697,6 +896,14 @@ module Google
         end
       end
       
+      class BasicService
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          hash :service_labels, as: 'serviceLabels'
+          property :service_type, as: 'serviceType'
+        end
+      end
+      
       class BasicSli
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -710,6 +917,13 @@ module Google
         end
       end
       
+      class BooleanTest
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :column, as: 'column'
+        end
+      end
+      
       class BucketOptions
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -729,6 +943,23 @@ module Google
         end
       end
       
+      class CloudFunctionV2Target
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :cloud_run_revision, as: 'cloudRunRevision', class: Google::Apis::MonitoringV3::MonitoredResource, decorator: Google::Apis::MonitoringV3::MonitoredResource::Representation
+      
+          property :name, as: 'name'
+        end
+      end
+      
+      class CloudRun
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :location, as: 'location'
+          property :service_name, as: 'serviceName'
+        end
+      end
+      
       class ClusterIstio
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -794,6 +1025,10 @@ module Google
       
           property :condition_monitoring_query_language, as: 'conditionMonitoringQueryLanguage', class: Google::Apis::MonitoringV3::MonitoringQueryLanguageCondition, decorator: Google::Apis::MonitoringV3::MonitoringQueryLanguageCondition::Representation
       
+          property :condition_prometheus_query_language, as: 'conditionPrometheusQueryLanguage', class: Google::Apis::MonitoringV3::PrometheusQueryLanguageCondition, decorator: Google::Apis::MonitoringV3::PrometheusQueryLanguageCondition::Representation
+      
+          property :condition_sql, as: 'conditionSql', class: Google::Apis::MonitoringV3::SqlCondition, decorator: Google::Apis::MonitoringV3::SqlCondition::Representation
+      
           property :condition_threshold, as: 'conditionThreshold', class: Google::Apis::MonitoringV3::MetricThreshold, decorator: Google::Apis::MonitoringV3::MetricThreshold::Representation
       
           property :display_name, as: 'displayName'
@@ -805,6 +1040,8 @@ module Google
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
           property :content, as: 'content'
+          property :json_path_matcher, as: 'jsonPathMatcher', class: Google::Apis::MonitoringV3::JsonPathMatcher, decorator: Google::Apis::MonitoringV3::JsonPathMatcher::Representation
+      
           property :matcher, as: 'matcher'
         end
       end
@@ -848,12 +1085,29 @@ module Google
         end
       end
       
+      class Criteria
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :filter, as: 'filter'
+          collection :policies, as: 'policies'
+        end
+      end
+      
       class Custom
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
         end
       end
       
+      class Daily
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :execution_time, as: 'executionTime', class: Google::Apis::MonitoringV3::TimeOfDay, decorator: Google::Apis::MonitoringV3::TimeOfDay::Representation
+      
+          property :periodicity, as: 'periodicity'
+        end
+      end
+      
       class Distribution
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -883,7 +1137,10 @@ module Google
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
           property :content, as: 'content'
+          collection :links, as: 'links', class: Google::Apis::MonitoringV3::Link, decorator: Google::Apis::MonitoringV3::Link::Representation
+      
           property :mime_type, as: 'mimeType'
+          property :subject, as: 'subject'
         end
       end
       
@@ -951,6 +1208,13 @@ module Google
         end
       end
       
+      class ForecastOptions
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :forecast_horizon, as: 'forecastHorizon'
+        end
+      end
+      
       class GetNotificationChannelVerificationCodeRequest
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -966,6 +1230,39 @@ module Google
         end
       end
       
+      class GkeNamespace
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :cluster_name, as: 'clusterName'
+          property :location, as: 'location'
+          property :namespace_name, as: 'namespaceName'
+          property :project_id, as: 'projectId'
+        end
+      end
+      
+      class GkeService
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :cluster_name, as: 'clusterName'
+          property :location, as: 'location'
+          property :namespace_name, as: 'namespaceName'
+          property :project_id, as: 'projectId'
+          property :service_name, as: 'serviceName'
+        end
+      end
+      
+      class GkeWorkload
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :cluster_name, as: 'clusterName'
+          property :location, as: 'location'
+          property :namespace_name, as: 'namespaceName'
+          property :project_id, as: 'projectId'
+          property :top_level_controller_name, as: 'topLevelControllerName'
+          property :top_level_controller_type, as: 'topLevelControllerType'
+        end
+      end
+      
       class GoogleMonitoringV3Range
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -985,18 +1282,33 @@ module Google
         end
       end
       
+      class Hourly
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :minute_offset, as: 'minuteOffset'
+          property :periodicity, as: 'periodicity'
+        end
+      end
+      
       class HttpCheck
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          collection :accepted_response_status_codes, as: 'acceptedResponseStatusCodes', class: Google::Apis::MonitoringV3::ResponseStatusCode, decorator: Google::Apis::MonitoringV3::ResponseStatusCode::Representation
+      
           property :auth_info, as: 'authInfo', class: Google::Apis::MonitoringV3::BasicAuthentication, decorator: Google::Apis::MonitoringV3::BasicAuthentication::Representation
       
           property :body, :base64 => true, as: 'body'
           property :content_type, as: 'contentType'
+          property :custom_content_type, as: 'customContentType'
           hash :headers, as: 'headers'
           property :mask_headers, as: 'maskHeaders'
           property :path, as: 'path'
+          property :ping_config, as: 'pingConfig', class: Google::Apis::MonitoringV3::PingConfig, decorator: Google::Apis::MonitoringV3::PingConfig::Representation
+      
           property :port, as: 'port'
           property :request_method, as: 'requestMethod'
+          property :service_agent_authentication, as: 'serviceAgentAuthentication', class: Google::Apis::MonitoringV3::ServiceAgentAuthentication, decorator: Google::Apis::MonitoringV3::ServiceAgentAuthentication::Representation
+      
           property :use_ssl, as: 'useSsl'
           property :validate_ssl, as: 'validateSsl'
         end
@@ -1023,6 +1335,14 @@ module Google
         end
       end
       
+      class JsonPathMatcher
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :json_matcher, as: 'jsonMatcher'
+          property :json_path, as: 'jsonPath'
+        end
+      end
+      
       class LabelDescriptor
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1057,6 +1377,14 @@ module Google
         end
       end
       
+      class Link
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :display_name, as: 'displayName'
+          property :url, as: 'url'
+        end
+      end
+      
       class ListAlertPoliciesResponse
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1067,6 +1395,16 @@ module Google
         end
       end
       
+      class ListAlertsResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :alerts, as: 'alerts', class: Google::Apis::MonitoringV3::Alert, decorator: Google::Apis::MonitoringV3::Alert::Representation
+      
+          property :next_page_token, as: 'nextPageToken'
+          property :total_size, as: 'totalSize'
+        end
+      end
+      
       class ListGroupMembersResponse
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1141,6 +1479,15 @@ module Google
         end
       end
       
+      class ListSnoozesResponse
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :next_page_token, as: 'nextPageToken'
+          collection :snoozes, as: 'snoozes', class: Google::Apis::MonitoringV3::Snooze, decorator: Google::Apis::MonitoringV3::Snooze::Representation
+      
+        end
+      end
+      
       class ListTimeSeriesResponse
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1150,6 +1497,7 @@ module Google
           collection :time_series, as: 'timeSeries', class: Google::Apis::MonitoringV3::TimeSeries, decorator: Google::Apis::MonitoringV3::TimeSeries::Representation
       
           property :unit, as: 'unit'
+          collection :unreachable, as: 'unreachable'
         end
       end
       
@@ -1180,6 +1528,13 @@ module Google
         end
       end
       
+      class LogMetadata
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          hash :extracted_labels, as: 'extractedLabels'
+        end
+      end
+      
       class MeshIstio
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1234,6 +1589,7 @@ module Google
           property :ingest_delay, as: 'ingestDelay'
           property :launch_stage, as: 'launchStage'
           property :sample_period, as: 'samplePeriod'
+          collection :time_series_resource_hierarchy_level, as: 'timeSeriesResourceHierarchyLevel'
         end
       end
       
@@ -1256,13 +1612,23 @@ module Google
       
           property :denominator_filter, as: 'denominatorFilter'
           property :duration, as: 'duration'
+          property :evaluation_missing_data, as: 'evaluationMissingData'
           property :filter, as: 'filter'
+          property :forecast_options, as: 'forecastOptions', class: Google::Apis::MonitoringV3::ForecastOptions, decorator: Google::Apis::MonitoringV3::ForecastOptions::Representation
+      
           property :threshold_value, as: 'thresholdValue'
           property :trigger, as: 'trigger', class: Google::Apis::MonitoringV3::Trigger, decorator: Google::Apis::MonitoringV3::Trigger::Representation
       
         end
       end
       
+      class Minutes
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :periodicity, as: 'periodicity'
+        end
+      end
+      
       class MonitoredResource
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1296,6 +1662,7 @@ module Google
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
           property :duration, as: 'duration'
+          property :evaluation_missing_data, as: 'evaluationMissingData'
           property :query, as: 'query'
           property :trigger, as: 'trigger', class: Google::Apis::MonitoringV3::Trigger, decorator: Google::Apis::MonitoringV3::Trigger::Representation
       
@@ -1337,10 +1704,19 @@ module Google
       
           property :launch_stage, as: 'launchStage'
           property :name, as: 'name'
+          collection :supported_tiers, as: 'supportedTiers'
           property :type, as: 'type'
         end
       end
       
+      class NotificationChannelStrategy
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :notification_channel_names, as: 'notificationChannelNames'
+          property :renotify_interval, as: 'renotifyInterval'
+        end
+      end
+      
       class NotificationRateLimit
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1376,6 +1752,13 @@ module Google
         end
       end
       
+      class PingConfig
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :pings_count, as: 'pingsCount'
+        end
+      end
+      
       class Point
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1396,6 +1779,29 @@ module Google
         end
       end
       
+      class PolicySnapshot
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :display_name, as: 'displayName'
+          property :name, as: 'name'
+          property :severity, as: 'severity'
+          hash :user_labels, as: 'userLabels'
+        end
+      end
+      
+      class PrometheusQueryLanguageCondition
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :alert_rule, as: 'alertRule'
+          property :disable_metric_validation, as: 'disableMetricValidation'
+          property :duration, as: 'duration'
+          property :evaluation_interval, as: 'evaluationInterval'
+          hash :labels, as: 'labels'
+          property :query, as: 'query'
+          property :rule_group, as: 'ruleGroup'
+        end
+      end
+      
       class QueryTimeSeriesRequest
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1444,6 +1850,22 @@ module Google
         end
       end
       
+      class ResponseStatusCode
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :status_class, as: 'statusClass'
+          property :status_value, as: 'statusValue'
+        end
+      end
+      
+      class RowCountTest
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :comparison, as: 'comparison'
+          property :threshold, :numeric_string => true, as: 'threshold'
+        end
+      end
+      
       class SendNotificationChannelVerificationCodeRequest
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1455,13 +1877,23 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :app_engine, as: 'appEngine', class: Google::Apis::MonitoringV3::AppEngine, decorator: Google::Apis::MonitoringV3::AppEngine::Representation
       
+          property :basic_service, as: 'basicService', class: Google::Apis::MonitoringV3::BasicService, decorator: Google::Apis::MonitoringV3::BasicService::Representation
+      
           property :cloud_endpoints, as: 'cloudEndpoints', class: Google::Apis::MonitoringV3::CloudEndpoints, decorator: Google::Apis::MonitoringV3::CloudEndpoints::Representation
       
+          property :cloud_run, as: 'cloudRun', class: Google::Apis::MonitoringV3::CloudRun, decorator: Google::Apis::MonitoringV3::CloudRun::Representation
+      
           property :cluster_istio, as: 'clusterIstio', class: Google::Apis::MonitoringV3::ClusterIstio, decorator: Google::Apis::MonitoringV3::ClusterIstio::Representation
       
           property :custom, as: 'custom', class: Google::Apis::MonitoringV3::Custom, decorator: Google::Apis::MonitoringV3::Custom::Representation
       
           property :display_name, as: 'displayName'
+          property :gke_namespace, as: 'gkeNamespace', class: Google::Apis::MonitoringV3::GkeNamespace, decorator: Google::Apis::MonitoringV3::GkeNamespace::Representation
+      
+          property :gke_service, as: 'gkeService', class: Google::Apis::MonitoringV3::GkeService, decorator: Google::Apis::MonitoringV3::GkeService::Representation
+      
+          property :gke_workload, as: 'gkeWorkload', class: Google::Apis::MonitoringV3::GkeWorkload, decorator: Google::Apis::MonitoringV3::GkeWorkload::Representation
+      
           property :istio_canonical_service, as: 'istioCanonicalService', class: Google::Apis::MonitoringV3::IstioCanonicalService, decorator: Google::Apis::MonitoringV3::IstioCanonicalService::Representation
       
           property :mesh_istio, as: 'meshIstio', class: Google::Apis::MonitoringV3::MeshIstio, decorator: Google::Apis::MonitoringV3::MeshIstio::Representation
@@ -1473,6 +1905,13 @@ module Google
         end
       end
       
+      class ServiceAgentAuthentication
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :type, as: 'type'
+        end
+      end
+      
       class ServiceLevelIndicator
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1499,6 +1938,18 @@ module Google
         end
       end
       
+      class Snooze
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :criteria, as: 'criteria', class: Google::Apis::MonitoringV3::Criteria, decorator: Google::Apis::MonitoringV3::Criteria::Representation
+      
+          property :display_name, as: 'displayName'
+          property :interval, as: 'interval', class: Google::Apis::MonitoringV3::TimeInterval, decorator: Google::Apis::MonitoringV3::TimeInterval::Representation
+      
+          property :name, as: 'name'
+        end
+      end
+      
       class SourceContext
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1513,6 +1964,23 @@ module Google
         end
       end
       
+      class SqlCondition
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :boolean_test, as: 'booleanTest', class: Google::Apis::MonitoringV3::BooleanTest, decorator: Google::Apis::MonitoringV3::BooleanTest::Representation
+      
+          property :daily, as: 'daily', class: Google::Apis::MonitoringV3::Daily, decorator: Google::Apis::MonitoringV3::Daily::Representation
+      
+          property :hourly, as: 'hourly', class: Google::Apis::MonitoringV3::Hourly, decorator: Google::Apis::MonitoringV3::Hourly::Representation
+      
+          property :minutes, as: 'minutes', class: Google::Apis::MonitoringV3::Minutes, decorator: Google::Apis::MonitoringV3::Minutes::Representation
+      
+          property :query, as: 'query'
+          property :row_count_test, as: 'rowCountTest', class: Google::Apis::MonitoringV3::RowCountTest, decorator: Google::Apis::MonitoringV3::RowCountTest::Representation
+      
+        end
+      end
+      
       class Status
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -1522,9 +1990,19 @@ module Google
         end
       end
       
+      class SyntheticMonitorTarget
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :cloud_function_v2, as: 'cloudFunctionV2', class: Google::Apis::MonitoringV3::CloudFunctionV2Target, decorator: Google::Apis::MonitoringV3::CloudFunctionV2Target::Representation
+      
+        end
+      end
+      
       class TcpCheck
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :ping_config, as: 'pingConfig', class: Google::Apis::MonitoringV3::PingConfig, decorator: Google::Apis::MonitoringV3::PingConfig::Representation
+      
           property :port, as: 'port'
         end
       end
@@ -1544,9 +2022,20 @@ module Google
         end
       end
       
+      class TimeOfDay
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :hours, as: 'hours'
+          property :minutes, as: 'minutes'
+          property :nanos, as: 'nanos'
+          property :seconds, as: 'seconds'
+        end
+      end
+      
       class TimeSeries
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :description, as: 'description'
           property :metadata, as: 'metadata', class: Google::Apis::MonitoringV3::MonitoredResourceMetadata, decorator: Google::Apis::MonitoringV3::MonitoredResourceMetadata::Representation
       
           property :metric, as: 'metric', class: Google::Apis::MonitoringV3::Metric, decorator: Google::Apis::MonitoringV3::Metric::Representation
@@ -1601,6 +2090,7 @@ module Google
       class Type
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :edition, as: 'edition'
           collection :fields, as: 'fields', class: Google::Apis::MonitoringV3::Field, decorator: Google::Apis::MonitoringV3::Field::Representation
       
           property :name, as: 'name'
@@ -1628,14 +2118,17 @@ module Google
       class UptimeCheckConfig
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :checker_type, as: 'checkerType'
           collection :content_matchers, as: 'contentMatchers', class: Google::Apis::MonitoringV3::ContentMatcher, decorator: Google::Apis::MonitoringV3::ContentMatcher::Representation
       
+          property :disabled, as: 'disabled'
           property :display_name, as: 'displayName'
           property :http_check, as: 'httpCheck', class: Google::Apis::MonitoringV3::HttpCheck, decorator: Google::Apis::MonitoringV3::HttpCheck::Representation
       
           collection :internal_checkers, as: 'internalCheckers', class: Google::Apis::MonitoringV3::InternalChecker, decorator: Google::Apis::MonitoringV3::InternalChecker::Representation
       
           property :is_internal, as: 'isInternal'
+          property :log_check_failures, as: 'logCheckFailures'
           property :monitored_resource, as: 'monitoredResource', class: Google::Apis::MonitoringV3::MonitoredResource, decorator: Google::Apis::MonitoringV3::MonitoredResource::Representation
       
           property :name, as: 'name'
@@ -1643,9 +2136,12 @@ module Google
           property :resource_group, as: 'resourceGroup', class: Google::Apis::MonitoringV3::ResourceGroup, decorator: Google::Apis::MonitoringV3::ResourceGroup::Representation
       
           collection :selected_regions, as: 'selectedRegions'
+          property :synthetic_monitor, as: 'syntheticMonitor', class: Google::Apis::MonitoringV3::SyntheticMonitorTarget, decorator: Google::Apis::MonitoringV3::SyntheticMonitorTarget::Representation
+      
           property :tcp_check, as: 'tcpCheck', class: Google::Apis::MonitoringV3::TcpCheck, decorator: Google::Apis::MonitoringV3::TcpCheck::Representation
       
           property :timeout, as: 'timeout'
+          hash :user_labels, as: 'userLabels'
         end
       end
       
